# eric7.Preferences.__init__

Package implementing the preferences interface.

The preferences interface consists of a class, which defines the default values for all configuration items and stores the actual values. These values are read and written to the eric7 preferences file by module functions. The data is stored in a file in a subdirectory of the users home directory. The individual configuration data is accessed by accessor functions defined on the module level. The module is simply imported wherever it is needed with the statement 'import Preferences'. Do not use 'from Preferences import *' to import it.

### Global Attributes

None

### Classes

Prefs | A class to hold all configuration items for the application.

### Functions

convertPasswords | Module function to convert all passwords.
eric6SettingsName | Function to generate the settings file name for eric6.
exportPreferences | Module function to export the current preferences.
getConda | Module function to retrieve the conda related settings.
getCooperation | Module function to retrieve the various Cooperation settings.
getCorba | Module function to retrieve the various Corba settings.
getDebugger | Module function to retrieve the debugger settings.
getDiffColour | Module function to retrieve the colours for the diff highlighter.
getDocuViewer | Module function to retrieve the Code Documentation Viewer related settings.
getEditor | Module function to retrieve the various editor settings.
getEditorAPI | Module function to retrieve the various lists of API files.
getEditorColour | Module function to retrieve the various editor marker colours.
getEditorExporter | Module function to retrieve the various editor exporters settings.
getEditorKeywords | Module function to retrieve the various lists of language keywords.
getEditorLexerAssoc | Module function to retrieve a lexer association.
getEditorLexerAssocs | Module function to retrieve all lexer associations.
getEditorOtherFonts | Module function to retrieve the various editor fonts except the lexer fonts.
getEditorTyping | Module function to retrieve the various editor typing settings.
getFlakes | Module function to retrieve the pyflakes related settings.
getGeometry | Module function to retrieve the display geometry.
getGraphics | Module function to retrieve the Graphics related settings.
getHelp | Module function to retrieve the various help settings.
getHexEditor | Module function to retrieve the Hex Editor related settings.
getIconEditor | Module function to retrieve the Icon Editor related settings.
getIcons | Module function to retrieve the various Icons settings.
getIrc | Module function to retrieve the IRC related settings.
getJedi | Function to retrieve the Jedi Assistant related settings.
getMicroPython | Module function to retrieve the MicroPython related settings.
getMultiProject | Module function to retrieve the various project handling settings.
getPip | Module function to retrieve the pip related settings.
getPluginManager | Module function to retrieve the plugin manager related settings.
getPrinter | Module function to retrieve the various printer settings.
getProject | Module function to retrieve the various project handling settings.
getProjectBrowserColour | Module function to retrieve the various project browser colours.
getProjectBrowserFlags | Module function to retrieve the various project browser flags settings.
getProtobuf | Module function to retrieve the various protobuf settings.
getPython | Module function to retrieve the Python settings.
getQt | Module function to retrieve the various Qt settings.
getQtDocDir | Module function to retrieve the Qt5DocDir/Qt6DocDir setting.
getQtTranslationsDir | Module function to retrieve the Qt6TranslationsDir setting depending on the current Qt version.
getSettings | Function to get a reference to the settings object.
getShell | Module function to retrieve the various shell settings.
getSystem | Module function to retrieve the various system settings.
getTasks | Module function to retrieve the Tasks related settings.
getTemplates | Module function to retrieve the Templates related settings.
getTrayStarter | Module function to retrieve the tray starter related settings.
getUI | Module function to retrieve the various UI settings.
getUILanguage | Module function to retrieve the language for the user interface.
getUser | Module function to retrieve the various user settings.
getVCS | Module function to retrieve the VCS related settings.
getVarFilters | Module function to retrieve the variables filter settings.
getViewManager | Module function to retrieve the selected viewmanager type.
getWebBrowser | Module function to retrieve the various web browser settings.
hasEric6Configuration | Function to check, if there is an old eric6 configuration.
importEric6Configuration | Function to import an old eric6 configuration.
importPreferences | Module function to import preferences from a file previously saved by the export function.
initPreferences | Module function to initialize the central configuration store.
initRecentSettings | Module function to initialize the central configuration store for recently opened files and projects.
isConfigured | Module function to check, if the the application has been configured.
readToolGroups | Module function to read the tool groups configuration.
removeProjectBrowserFlags | Module function to remove a project browser flags setting.
resetLayout | Module function to set a flag not storing the current layout.
saveResetLayout | Module function to save the reset layout.
saveToolGroups | Module function to write the tool groups configuration.
setConda | Module function to store the conda related settings.
setConfigured | Function to set the configured flag.
setCooperation | Module function to store the various Cooperation settings.
setCorba | Module function to store the various Corba settings.
setDebugger | Module function to store the debugger settings.
setDiffColour | Module function to store the diff highlighter colours.
setDocuViewer | Module function to store the Code Documentation Viewer related settings.
setEditor | Module function to store the various editor settings.
setEditorAPI | Module function to store the various lists of API files.
setEditorColour | Module function to store the various editor marker colours.
setEditorExporter | Module function to store the various editor exporters settings.
setEditorKeywords | Module function to store the various lists of language keywords.
setEditorLexerAssocs | Module function to retrieve all lexer associations.
setEditorOtherFonts | Module function to store the various editor fonts except the lexer fonts.
setEditorTyping | Module function to store the various editor typing settings.
setFlakes | Module function to store the pyflakes related settings.
setGeometry | Module function to store the display geometry.
setGraphics | Module function to store the Graphics related settings.
setHelp | Module function to store the various help settings.
setHexEditor | Module function to store the Hex Editor related settings.
setIconEditor | Module function to store the Icon Editor related settings.
setIcons | Module function to store the various Icons settings.
setIrc | Module function to store the IRC related settings.
setJedi | Public method to store the various refactoring settings.
setMicroPython | Module function to store the MicroPython settings.
setMultiProject | Module function to store the various project handling settings.
setPip | Module function to store the pip related settings.
setPluginManager | Module function to store the plugin manager related settings.
setPrinter | Module function to store the various printer settings.
setProject | Module function to store the various project handling settings.
setProjectBrowserColour | Module function to store the various project browser colours.
setProjectBrowserFlags | Module function to store the various project browser flags settings.
setProjectBrowserFlagsDefault | Module function to store the various project browser flags settings.
setProtobuf | Module function to store the various protobuf settings.
setPython | Module function to store the Python settings.
setQt | Module function to store the various Qt settings.
setShell | Module function to store the various shell settings.
setSystem | Module function to store the various system settings.
setTasks | Module function to store the Tasks related settings.
setTemplates | Module function to store the Templates related settings.
setTrayStarter | Module function to store the tray starter related settings.
setUI | Module function to store the various UI settings.
setUILanguage | Module function to store the language for the user interface.
setUser | Module function to store the various user settings.
setVCS | Module function to store the VCS related settings.
setVarFilters | Module function to store the variables filter settings.
setViewManager | Module function to store the selected viewmanager type.
setWebBrowser | Module function to store the various web browser settings.
shouldResetLayout | Module function to indicate a reset of the layout.
syncPreferences | Module function to sync the preferences to disk.
toBool | Module function to convert a value to bool.
toByteArray | Module function to convert a value to a byte array.
toDict | Module function to convert a value to a dictionary.
toList | Module function to convert a value to a list.

## Prefs

A class to hold all configuration items for the application.

### Derived from

None

### Class Attributes

condaDefaults
cooperationDefaults
corbaDefaults
debuggerDefaults
diffColourDefaults
docuViewerDefaults
editorColourDefaults
editorDefaults
editorExporterDefaults
editorOtherFontsDefaults
editorTypingDefaults
geometryDefaults
graphicsDefaults
helpDefaults
hexEditorDefaults
iconEditorDefaults
iconsDefaults
ircDefaults
jediDefaults
microPythonDefaults
multiProjectDefaults
pipDefaults
pluginManagerDefaults
printerDefaults
projectBrowserColourDefaults
projectBrowserFlagsDefaults
projectDefaults
protobufDefaults
pyflakesDefaults
pythonDefaults
qtDefaults
resetLayout
shellDefaults
sysDefaults
tasksDefaults
templatesDefaults
trayStarterDefaults
uiDefaults
userDefaults
varDefaults
vcsDefaults
webBrowserDefaults
webEngineSettingsIntitialized

### Class Methods

initWebEngineSettingsDefaults | Class method to initialize the web engine settings related defaults.

### Methods

None

### Static Methods

None

#### Prefs.initWebEngineSettingsDefaults (class method)

initWebEngineSettingsDefaults()

Class method to initialize the web engine settings related defaults.

Up

## convertPasswords

convertPasswords(oldPassword, newPassword)

Module function to convert all passwords.

oldPassword
  current master password (string)
newPassword
  new master password (string)

Up

## eric6SettingsName

eric6SettingsName()

Function to generate the settings file name for eric6.

Return:
  settings file name

Return Type:
  str

Up

## exportPreferences

exportPreferences()

Module function to export the current preferences.

Up

## getConda

getConda(key)

Module function to retrieve the conda related settings.

key
  the key of the value to get

Return:
  the requested conda value

Up

## getCooperation

getCooperation(key)

Module function to retrieve the various Cooperation settings.

key
  the key of the value to get

Return:
  the requested UI setting

Up

## getCorba

getCorba(key)

Module function to retrieve the various Corba settings.

key
  the key of the value to get

Return:
  the requested corba setting

Up

## getDebugger

getDebugger(key)

Module function to retrieve the debugger settings.

key (str)
  the key of the value to get

Return:
  the requested debugger setting

Return Type:
  Any

Up

## getDiffColour

getDiffColour(key)

Module function to retrieve the colours for the diff highlighter.

key
  the key of the value to get

Return:
  the requested diff colour

Up

## getDocuViewer

getDocuViewer(key)

Module function to retrieve the Code Documentation Viewer related settings.

key
  the key of the value to get

Return:
  the requested Code Documentation Viewer value

Up

## getEditor

getEditor(key)

Module function to retrieve the various editor settings.

key
  the key of the value to get

Return:
  the requested editor setting

Up

## getEditorAPI

getEditorAPI(language, projectType="")

Module function to retrieve the various lists of API files.

language (str)
  language of the API list
projectType (str)
  project type of the API list

Return:
  requested list of API files

Return Type:
  list of str

Up

## getEditorColour

getEditorColour(key)

Module function to retrieve the various editor marker colours.

key
  the key of the value to get

Return:
  the requested editor colour

Up

## getEditorExporter

getEditorExporter(key)

Module function to retrieve the various editor exporters settings.

key
  the key of the value to get

Return:
  the requested editor setting

Up

## getEditorKeywords

getEditorKeywords(key)

Module function to retrieve the various lists of language keywords.

key
  the key of the value to get

Return:
  the requested list of language keywords (list of strings)

Up

## getEditorLexerAssoc

getEditorLexerAssoc(filename)

Module function to retrieve a lexer association.

filename
  filename used to determine the associated lexer language (string)

Return:
  the requested lexer language (string)

Up

## getEditorLexerAssocs

getEditorLexerAssocs()

Module function to retrieve all lexer associations.

Return:
  a reference to the list of lexer associations (dictionary of strings)

Up

## getEditorOtherFonts

getEditorOtherFonts(key)

Module function to retrieve the various editor fonts except the lexer fonts.

key
  the key of the value to get

Return:
  the requested editor font (QFont)

Up

## getEditorTyping

getEditorTyping(key)

Module function to retrieve the various editor typing settings.

key
  the key of the value to get

Return:
  the requested editor setting

Up

## getFlakes

getFlakes(key)

Module function to retrieve the pyflakes related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getGeometry

getGeometry(key)

Module function to retrieve the display geometry.

key
  the key of the value to get

Return:
  the requested geometry setting

Up

## getGraphics

getGraphics(key)

Module function to retrieve the Graphics related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getHelp

getHelp(key)

Module function to retrieve the various help settings.

key
  the key of the value to get

Return:
  the requested help setting

Up

## getHexEditor

getHexEditor(key)

Module function to retrieve the Hex Editor related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getIconEditor

getIconEditor(key)

Module function to retrieve the Icon Editor related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getIcons

getIcons(key)

Module function to retrieve the various Icons settings.

key
  the key of the value to get

Return:
  the requested Icons setting

Up

## getIrc

getIrc(key)

Module function to retrieve the IRC related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getJedi

getJedi(key)

Function to retrieve the Jedi Assistant related settings.

key (str)
  the key of the value to get

Return:
  the requested jedi assistant setting

Return Type:
  Any

Up

## getMicroPython

getMicroPython(key)

Module function to retrieve the MicroPython related settings.

key
  the key of the value to get

Return:
  the requested MicroPython value

Up

## getMultiProject

getMultiProject(key)

Module function to retrieve the various project handling settings.

key
  the key of the value to get

Return:
  the requested project setting

Up

## getPip

getPip(key)

Module function to retrieve the pip related settings.

key
  the key of the value to get

Return:
  the requested pip value

Up

## getPluginManager

getPluginManager(key)

Module function to retrieve the plugin manager related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getPrinter

getPrinter(key)

Module function to retrieve the various printer settings.

key
  the key of the value to get

Return:
  the requested printer setting

Up

## getProject

getProject(key)

Module function to retrieve the various project handling settings.

key
  the key of the value to get

Return:
  the requested project setting

Up

## getProjectBrowserColour

getProjectBrowserColour(key)

Module function to retrieve the various project browser colours.

key
  the key of the value to get

Return:
  the requested project browser colour

Up

## getProjectBrowserFlags

getProjectBrowserFlags(key)

Module function to retrieve the various project browser flags settings.

key
  the key of the value to get

Return:
  the requested project setting

Up

## getProtobuf

getProtobuf(key)

Module function to retrieve the various protobuf settings.

key (str)
  the key of the value to get

Return:
  the requested protobuf setting

Return Type:
  any

Up

## getPython

getPython(key)

Module function to retrieve the Python settings.

key
  the key of the value to get

Return:
  the requested debugger setting

Up

## getQt

getQt(key)

Module function to retrieve the various Qt settings.

key
  the key of the value to get

Return:
  the requested Qt setting

Up

## getQtDocDir

getQtDocDir(version)

Module function to retrieve the Qt5DocDir/Qt6DocDir setting.

version (int)
  Qt version to get documentation directory for

Return:
  the requested Qt5DocDir/Qt6DocDir setting

Return Type:
  str

Up

## getQtTranslationsDir

getQtTranslationsDir()

Module function to retrieve the Qt6TranslationsDir setting depending on the current Qt version.

Return:
  the requested setting (string)

Up

## getSettings

getSettings()

Function to get a reference to the settings object.

Return:
  reference to the settings object

Return Type:
  QSettings

Up

## getShell

getShell(key)

Module function to retrieve the various shell settings.

key
  the key of the value to get

Return:
  the requested shell setting

Up

## getSystem

getSystem(key)

Module function to retrieve the various system settings.

key
  the key of the value to get

Return:
  the requested system setting

Up

## getTasks

getTasks(key)

Module function to retrieve the Tasks related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getTemplates

getTemplates(key)

Module function to retrieve the Templates related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getTrayStarter

getTrayStarter(key)

Module function to retrieve the tray starter related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getUI

getUI(key)

Module function to retrieve the various UI settings.

key
  the key of the value to get

Return:
  the requested UI setting

Up

## getUILanguage

getUILanguage()

Module function to retrieve the language for the user interface.

Return:
  the language for the UI

Up

## getUser

getUser(key)

Module function to retrieve the various user settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getVCS

getVCS(key)

Module function to retrieve the VCS related settings.

key
  the key of the value to get

Return:
  the requested user setting

Up

## getVarFilters

getVarFilters()

Module function to retrieve the variables filter settings.

Return:
  a tuple defining the variables filter

Up

## getViewManager

getViewManager()

Module function to retrieve the selected viewmanager type.

Return:
  the viewmanager type

Up

## getWebBrowser

getWebBrowser(key)

Module function to retrieve the various web browser settings.

key
  the key of the value to get

Return:
  the requested help setting

Up

## hasEric6Configuration

hasEric6Configuration()

Function to check, if there is an old eric6 configuration.

Return:
  flag indicating the existence of an eric6 configuration

Return Type:
  bool

Up

## importEric6Configuration

importEric6Configuration()

Function to import an old eric6 configuration.

Up

## importPreferences

importPreferences()

Module function to import preferences from a file previously saved by the export function.

Up

## initPreferences

initPreferences()

Module function to initialize the central configuration store.

Up

## initRecentSettings

initRecentSettings()

Module function to initialize the central configuration store for recently opened files and projects.

This function is called once upon import of the module.

Up

## isConfigured

isConfigured()

Module function to check, if the the application has been configured.

Return:
  flag indicating the configured status (boolean)

Up

## readToolGroups

readToolGroups()

Module function to read the tool groups configuration.

Return:
  list of tuples defing the tool groups

Up

## removeProjectBrowserFlags

removeProjectBrowserFlags(key)

Module function to remove a project browser flags setting.

key
  the key of the setting to be removed

Up

## resetLayout

resetLayout()

Module function to set a flag not storing the current layout.

Up

## saveResetLayout

saveResetLayout()

Module function to save the reset layout.

Up

## saveToolGroups

saveToolGroups(toolGroups, currentGroup)

Module function to write the tool groups configuration.

toolGroups
  reference to the list of tool groups
currentGroup
  index of the currently selected tool group (integer)

Up

## setConda

setConda(key, value)

Module function to store the conda related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setConfigured

setConfigured()

Function to set the configured flag.

Up

## setCooperation

setCooperation(key, value)

Module function to store the various Cooperation settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setCorba

setCorba(key, value)

Module function to store the various Corba settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setDebugger

setDebugger(key, value)

Module function to store the debugger settings.

key (str)
  the key of the setting to be set
value (Any)
  the value to be set

Up

## setDiffColour

setDiffColour(key, value)

Module function to store the diff highlighter colours.

key
  the key of the colour to be set
value
  the colour to be set

Up

## setDocuViewer

setDocuViewer(key, value)

Module function to store the Code Documentation Viewer related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setEditor

setEditor(key, value)

Module function to store the various editor settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setEditorAPI

setEditorAPI(language, projectType, apilist)

Module function to store the various lists of API files.

language (str)
  language of the API list
projectType (str)
  project type of the API list
apilist (list of str)
  list of API files

Up

## setEditorColour

setEditorColour(key, value)

Module function to store the various editor marker colours.

key
  the key of the colour to be set
value
  the colour to be set

Up

## setEditorExporter

setEditorExporter(key, value)

Module function to store the various editor exporters settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setEditorKeywords

setEditorKeywords(key, keywordsLists)

Module function to store the various lists of language keywords.

key
  the key of the api to be set
keywordsLists
  the list of language keywords (list of strings)

Up

## setEditorLexerAssocs

setEditorLexerAssocs(assocs)

Module function to retrieve all lexer associations.

assocs
  dictionary of lexer associations to be set

Up

## setEditorOtherFonts

setEditorOtherFonts(key, font)

Module function to store the various editor fonts except the lexer fonts.

key
  the key of the font to be set
font
  the font to be set (QFont)

Up

## setEditorTyping

setEditorTyping(key, value)

Module function to store the various editor typing settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setFlakes

setFlakes(key, value)

Module function to store the pyflakes related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setGeometry

setGeometry(key, value)

Module function to store the display geometry.

key
  the key of the setting to be set
value
  the geometry to be set

Up

## setGraphics

setGraphics(key, value)

Module function to store the Graphics related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setHelp

setHelp(key, value)

Module function to store the various help settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setHexEditor

setHexEditor(key, value)

Module function to store the Hex Editor related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setIconEditor

setIconEditor(key, value)

Module function to store the Icon Editor related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setIcons

setIcons(key, value)

Module function to store the various Icons settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setIrc

setIrc(key, value)

Module function to store the IRC related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setJedi

setJedi(key, value)

Public method to store the various refactoring settings.

key (str)
  the key of the setting to be set
value (Any)
  the value to be set

Up

## setMicroPython

setMicroPython(key, value)

Module function to store the MicroPython settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setMultiProject

setMultiProject(key, value)

Module function to store the various project handling settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setPip

setPip(key, value)

Module function to store the pip related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setPluginManager

setPluginManager(key, value)

Module function to store the plugin manager related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setPrinter

setPrinter(key, value)

Module function to store the various printer settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setProject

setProject(key, value)

Module function to store the various project handling settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setProjectBrowserColour

setProjectBrowserColour(key, value)

Module function to store the various project browser colours.

key
  the key of the colour to be set
value
  the colour to be set

Up

## setProjectBrowserFlags

setProjectBrowserFlags(key, value)

Module function to store the various project browser flags settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setProjectBrowserFlagsDefault

setProjectBrowserFlagsDefault(key, value)

Module function to store the various project browser flags settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setProtobuf

setProtobuf(key, value)

Module function to store the various protobuf settings.

key (str)
  the key of the setting to be set
value (any)
  the value to be set

Up

## setPython

setPython(key, value)

Module function to store the Python settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setQt

setQt(key, value)

Module function to store the various Qt settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setShell

setShell(key, value)

Module function to store the various shell settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setSystem

setSystem(key, value)

Module function to store the various system settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setTasks

setTasks(key, value)

Module function to store the Tasks related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setTemplates

setTemplates(key, value)

Module function to store the Templates related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setTrayStarter

setTrayStarter(key, value)

Module function to store the tray starter related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setUI

setUI(key, value)

Module function to store the various UI settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setUILanguage

setUILanguage(lang)

Module function to store the language for the user interface.

lang
  the language

Up

## setUser

setUser(key, value)

Module function to store the various user settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setVCS

setVCS(key, value)

Module function to store the VCS related settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## setVarFilters

setVarFilters(filters)

Module function to store the variables filter settings.

filters
  variable filters to set

Up

## setViewManager

setViewManager(vm)

Module function to store the selected viewmanager type.

vm
  the viewmanager type

Up

## setWebBrowser

setWebBrowser(key, value)

Module function to store the various web browser settings.

key
  the key of the setting to be set
value
  the value to be set

Up

## shouldResetLayout

shouldResetLayout()

Module function to indicate a reset of the layout.

Return:
  flag indicating a reset of the layout (boolean)

Up

## syncPreferences

syncPreferences()

Module function to sync the preferences to disk.

In addition to syncing, the central configuration store is reinitialized as well.

Up

## toBool

toBool(value)

Module function to convert a value to bool.

value
  value to be converted

Return:
  converted data

Up

## toByteArray

toByteArray(value)

Module function to convert a value to a byte array.

value
  value to be converted

Return:
  converted data

Up

## toDict

toDict(value)

Module function to convert a value to a dictionary.

value
  value to be converted

Return:
  converted data

Up

## toList

toList(value)

Module function to convert a value to a list.

value
  value to be converted

Return:
  converted data

Up